@@ -15,7 +15,7 @@ from rpmlint.pkg import FakePkg, get_installed_pkgs, Pkg
 from rpmlint.version import __version__
 
 
-class Lint(object):
+class Lint:
     """
     Generic object handling the basic rpmlint operations
     """
@@ -26,7 +26,7 @@ class Lint(object):
         self.options = options
         self.packages_checked = 0
         self.specfiles_checked = 0
-        self.check_duration = defaultdict(lambda: 0)
+        self.check_duration = defaultdict(int)
         if options['config']:
             self.config = Config(options['config'])
         else:
@@ -93,8 +93,11 @@ class Lint(object):
         self._maybe_print_reports()
 
         duration = time.monotonic() - start
+        error_messages = self.output.printed_messages['E']
+        warning_messages = self.output.printed_messages['W']
         msg = string_center(f'{self.packages_checked} packages and {self.specfiles_checked} specfiles checked; '
-                            f'{self.output.printed_messages["E"]} errors, {self.output.printed_messages["W"]} warnings, '
+                            f'{error_messages} errors, {warning_messages} warnings'
+                            f', {self.output.filtered_out} filtered, '
                             f'{self.output.score} badness; has taken {duration:.1f} s', '=')
         print(f'{quit_color}{msg}{Color.Reset}')
 
@@ -130,7 +133,11 @@ class Lint(object):
         total_checked_files = max(checked_files) if checked_files else ''
         print(f'{Color.Bold}Check time report{Color.Reset} (>{PERCENT_THRESHOLD}% & >{TIME_THRESHOLD}s):')
 
-        print(f'{Color.Bold}    {"Check":32s} {"Duration (in s)":>12} {"Fraction (in %)":>17}  Checked files{Color.Reset}')
+        check = format('Check', '32s')
+        duration = format('Duration (in s)', '>12')
+        fraction = format('Fraction (in %)', '>17')
+        print(f'{Color.Bold}    {check} {duration} {fraction}  Checked files{Color.Reset}')
+
         for check, duration in sorted(self.check_duration.items(), key=operator.itemgetter(1), reverse=True):
             fraction = 100.0 * duration / total
             if fraction < PERCENT_THRESHOLD or duration < TIME_THRESHOLD:
@@ -142,7 +149,8 @@ class Lint(object):
                 if checked:
                     checked_files = checked
             print(f'    {check:32s} {duration:15.1f} {self._get_color_time_report_value(fraction)} {checked_files:>14}')
-        print(f'    {"TOTAL":32s} {total:15.1f} {100:17.1f} {total_checked_files:>14}\n')
+
+        print(f'    {"TOTAL":32s} {total:15.1f} {100:17.1f} {total_checked_files:>14}\n')       # noqa Q000
 
     def _print_cprofile(self):
         N = 30
@@ -180,7 +188,7 @@ class Lint(object):
             # do this only in a case where there is one folder parameter or one file
             # to avoid multiple folders handling
             rpmlintrc = []
-            if not len(self.options['rpmfile']) == 1:
+            if len(self.options['rpmfile']) != 1:
                 return
             pkg = self.options['rpmfile'][0]
             if pkg.is_file():
@@ -216,6 +224,7 @@ class Lint(object):
     def validate_installed_packages(self, packages):
         for pkg in packages:
             self.run_checks(pkg, pkg == packages[-1])
+            self.reset_checks()
 
     def validate_files(self, files):
         """
@@ -235,6 +244,7 @@ class Lint(object):
         packages = sorted(packages)
         for pkg in packages:
             self.validate_file(pkg, pkg == packages[-1])
+            self.reset_checks()
 
     def _expand_filelist(self, files):
         packages = []
@@ -250,7 +260,8 @@ class Lint(object):
             if pname.suffix == '.rpm' or pname.suffix == '.spm':
                 with Pkg(pname, self.config.configuration['ExtractDir'],
                          verbose=self.config.info) as pkg:
-                    self.check_duration['rpm2cpio'] += pkg.extraction_time
+                    for k, v in pkg.timers.items():
+                        self.check_duration[k] += v
                     self.run_checks(pkg, is_last)
             elif pname.suffix == '.spec':
                 with FakePkg(pname) as pkg:
@@ -295,8 +306,15 @@ class Lint(object):
         """
         for message in messages:
             explanation = self.output.get_description(message, config)
+            if not explanation:
+                # check if it's a WarnOnFunction warning configuration
+                forbidden_functions = config.configuration['WarnOnFunction']
+                if message in forbidden_functions:
+                    explanation = forbidden_functions[message].get('description')
+
             if not explanation:
                 explanation = 'Unknown message, please report a bug if the description should be present.\n\n'
+
             print(f'{message}:\n{explanation}')
 
     def load_checks(self):
@@ -315,6 +333,13 @@ class Lint(object):
             if not selected_checks or check in selected_checks:
                 self.checks[check] = self.load_check(check)
 
+    def reset_checks(self):
+        """
+        Reset all check objects to set to the default state
+        """
+        for check in self.checks.values():
+            check.reset()
+
     def load_check(self, name):
         """Load a (check) module by its name, unless it is already loaded."""
         module = importlib.import_module(f'.{name}', package='rpmlint.checks')
