@@ -3,7 +3,8 @@ from rpm import RPMFILE_CONFIG, RPMFILE_NOREPLACE
 from Testing import get_tested_mock_package
 
 
-CONFIGFILES = get_tested_mock_package(
+ConfigFilesBrokenPackage = get_tested_mock_package(
+    lazyload=True,
     files={
         '/etc/conffile1': {'metadata': {'flags': RPMFILE_CONFIG}},
         '/var/conffile2': {'metadata': {'flags': RPMFILE_CONFIG}},
@@ -11,17 +12,9 @@ CONFIGFILES = get_tested_mock_package(
     }
 )
 
-CONFIGFILES2 = get_tested_mock_package(
-    files=[
-        'tmp/foo/my.log',
-        'tmp/foo2/my.log',
-        'etc/logrotate.d/logrotate2.conf',
-        'etc/logrotate.d/logrotate.conf',
-    ]
-)
 
-
-CONFIGFILES3 = get_tested_mock_package(
+ConfigFilesOkPackage = get_tested_mock_package(
+    lazyload=True,
     files={
         '/etc/conffile1': {'metadata': {'flags': RPMFILE_CONFIG & RPMFILE_NOREPLACE}},
         '/var/conffile2': {'metadata': {'flags': RPMFILE_CONFIG & RPMFILE_NOREPLACE}},
