@@ -1,8 +1,9 @@
+from mockdata.mock_mixed_ownership import MixedOwnershipPackage
 import pytest
 from rpmlint.checks.MixedOwnershipCheck import MixedOwnershipCheck
 from rpmlint.filter import Filter
 
-from Testing import CONFIG, get_tested_package
+from Testing import CONFIG
 
 
 @pytest.fixture(scope='function', autouse=True)
@@ -13,10 +14,10 @@ def mixedownershipcheck():
     return output, test
 
 
-@pytest.mark.parametrize('package', ['binary/mixed-ownership'])
-def test_mixed_ownership(tmp_path, package, mixedownershipcheck):
+@pytest.mark.parametrize('package', [MixedOwnershipPackage])
+def test_mixed_ownership(package, mixedownershipcheck):
     output, test = mixedownershipcheck
-    test.check(get_tested_package(package, tmp_path))
+    test.check(package)
     out = output.print_results(output.results)
     assert 'noproblem' not in out
     assert 'file-parent-ownership-mismatch Path "/var/lib/badfolder/broken1" owned by "root" is stored in directory owned by "nobody"' in out
